@@ -6,9 +6,10 @@ import win32con
 import webbrowser
 import os
 import subprocess
-from xyw_macro.win32 import send_kb_event, send_unicode
+from xyw_macro.macro import Macro
+from xyw_macro.win32 import send_kb_event, send_unicode, change_language_layout
 from xyw_macro.hook import VK
-from xyw_macro.contants import SLEEP_TIME
+from xyw_macro.contants import SLEEP_TIME, ZH_LANGUAGE, EN_LANGUAGE, BAIDU_LANGUAGE
 
 
 def press_key(v_key):
@@ -36,6 +37,7 @@ def touch_key(v_key):
     :return:
     """
     press_key(v_key)
+    random_sleep(0.01)
     release_key(v_key)
 
 
@@ -106,6 +108,7 @@ def input_chars(chars):
     """
     for char in chars:
         send_unicode(char)
+        random_sleep(0.01)
 
 
 def open_url(url, browser_path=None):
@@ -151,6 +154,33 @@ def confirm_mac(mac):
         raise TypeError('param mac must be string or list')
 
 
+def change_to_zh():
+    """
+    切换为中文输入法，优先切换为百度输入法
+    :return:
+    """
+    tem = change_language_layout(BAIDU_LANGUAGE)  # 适配win7系统
+    if not tem:
+        change_language_layout(ZH_LANGUAGE)
+
+
+def change_to_en():
+    """
+    切换为英文输入法
+    :return:
+    """
+    change_language_layout(EN_LANGUAGE)
+
+
+def change_to_config(index):
+    """
+    切换到指定配置
+    :param index: 配置索引（0开始）
+    :return:
+    """
+    Macro().current_config = index
+
+
 if __name__ == '__main__':
     # print(random_sleep(0.2, 0.25))
     # print(get_clipboard_files())
@@ -164,4 +194,6 @@ if __name__ == '__main__':
     # print(run_cmd(r"D:\Program Files (x86)\Everything\Everything.exe"))
     # print(run_cmd(r"C:\Program Files (x86)\WXWork\WXWork.exe"))
     # print(get_mac())
-    print(confirm_mac('0C-9D-92-0F-42-6E'))
+    # print(confirm_mac('0C-9D-92-0F-42-6E'))
+    # change_to_en()
+    change_language_layout(-0x1fddf7fc)
