@@ -182,7 +182,7 @@ def change_language_layout(language):
     hwnd = win32gui.GetForegroundWindow()
     im_list = win32api.GetKeyboardLayoutList()
     im_list = list(map(hex, im_list))
-    print(im_list)
+    # print(im_list)
 
     if hex(language) not in im_list:
         win32api.LoadKeyboardLayout('0000' + hex(language)[-4:], 1)
